/*	CompleteAccess.h

	Ocean Software, Inc.
	1994
*/


#define CA_COMPLETE_ACCESS_NAME	"Complete Access Server"

//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//	Application API
//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@protocol CA_Application_API
- currentLayout;
- currentContainer;
- getContainers:(List *)containers;
- openComponentNamed:(const char *)filespec;
- openContainerNamed:(const char *)filespec;
- terminate:sender;
- hide:sender;
- unhide:sender;
- unhideWithoutActivation:sender;
@end


//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//	Container API
//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@protocol CA_Container_API
- delegate;
- getDataSetNamed:(const char *)name;
- getDataSets:(List *)dataSets;
- getLayoutNamed:(const char *)name;
- getLayouts:(List *)layouts;
- getQueryNamed:(const char *)name;
- getQueries:(List *)queries;
- getCalculationNamed:(const char *)name;
- getCalculations:(List *)calculations;
@end

@protocol CA_Container_Delegate_API
- window;
- container;
- addComponent:component;
- removeComponent:component;
- selectComponent:component;
- openComponent:component;
- closeLayout:component;
- layout2LayoutView:component;
- (int)save;
- (int)saveAs:(const char *)filespec;
- (int)saveTo:(const char *)filespec;
- (int)revert;
- closeContainerWindow;
@end


//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//	Layout API
//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

@protocol CA_Layout_API
- (const char *)name;
- container;
@end

@protocol CA_LayoutView_API
- delegate;
- container;
- (int)layoutType;
- setTo:(unsigned int)gotoRecNum;
- (unsigned int)currentPosition;
- (unsigned int)recordCount;
- getSortCriteria:(List *)sortCriteria;
- setSortCriteria:(List *)sortCriteria;
- getSelectCriteria:(List *)selectCriteria;
- setSelectCriteria:(List *)selectCriteria;
- showAbortPanelWhilePrinting:(BOOL)abort;
- printPSCode:sender;
- faxPSCode:sender;
- printFromRecord:(unsigned int)from
			toRecord:(unsigned int)to;
- emailFromRecord:(unsigned int)fromRecord
			toRecord:(unsigned int)toRecord
			andAutoSent:(BOOL)autoSend
			subject:(const char *)subject
			modelPathForAddress:(const char *)modelPath;
@end

@protocol CA_LayoutView_Delegate_API
- layout;
- window;
- layoutView;
- container;
- closeLayoutWindow;
@end


//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//	Data Set API
//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

#define DATA_ACCESS_IMPORT	"CA_DataAccess_Import"
#define DATA_ACCESS_EXPORT	"CA_DataAccess_Export"
#define DATA_ACCESS_EOF		"CA_DataAccess_EOF"
#define DATA_ACCESS_DBKIT	"CA_DataAccess_DBKit"

@protocol CA_DataSet_API
- container;
- (BOOL)containsModel;
- (BOOL)containsData;
- reset;
- resetData;
- getDataAccessOfClass:(const char *)accessClass;
@end

@protocol CA_DataAccess_Import_API
- (const char *)importPath;
- setImportPath:(const char *)importPath;
- getImportFields:(List *)importFields;
- (BOOL)firstLineIsData;
- setFirstLineIsData:(BOOL)firstLineIsData;
- (const char *)fieldDelimiter;
- setFieldDelimiter:(const char *)fieldDelimiter;
- (const char *)recordDelimiter;
- setRecordDelimiter:(const char *)recordDelimiter;
- (BOOL)autoIndexPossible;
- (BOOL)incompleteKeyMapping;
- setAutoIndex:(BOOL)autoIndex;
- readStructure;
- generateModel;
- smartImport;
- putRecords;
@end

@protocol CA_DataAccess_Export_API
- (const char *)exportPath;
- setExportPath:(const char *)exportPath;
- getExportOrder:(List *)exportOrder;
- (BOOL)firstLineIsData;
- setFirstLineIsData:(BOOL)firstLineIsData;
- (const char *)fieldDelimiter;
- setFieldDelimiter:(const char *)fieldDelimiter;
- (const char *)recordDelimiter;
- setRecordDelimiter:(const char *)recordDelimiter;
- getSortCriteria:(List *)sortCriteria;
- setSortCriteria:(List *)sortCriteria;
- getSelecttCriteria:(List *)selectCriteria;
- setSelecttCriteria:(List *)selectCriteria;
- (BOOL)getRecords;
@end

@protocol CA_DataAccess_DBKit_API
- database;
- setDatabase:database;
- recordList2DataSet:recordList;
- binder2DataSet:binder;
- executeQueryNamed:(const char *)queryNamed;
- executeQualifier:qualifier
			withSortOrder:sortOrder;
- (const char *)queryName;
- setQueryName:(const char *)queryName;
- (BOOL)retrieveUnlimitedRecords;
- setRetrieveUnlimitedRecords:(BOOL)unlimited;
- (int)recordLimit;
- setRecordLimit:(int)recordLimit;
- (BOOL)recordLimitReached;
- (BOOL)isCompatibleDatabase:database;
@end

@protocol CA_DataAccess_EOF_API		// Not implemented in v1.0
@end


//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
//	Sort and Select API
//	%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

