/*	Controller.m

	Ocean Software, Inc.
	1994
*/

#import "Controller.h"
#import "CompleteAccess_API.h"

@implementation Controller

/*******************/
/* Private Methods */
/*******************/

- dataSet;
{
	List	*list;
	id		dataSet;
	
	list = [[List allocFromZone:[self zone]] init];
	[fContainer getDataSets:list];
	dataSet = [list objectAt:0];
	[list free];
	
	return dataSet;
} /* dataSet */



/**********************/
/* Connection Methods */
/**********************/

- launchCompleteAccess:sender;
{
	[[Application workspace] launchApplication:"CompleteAccess"];
	return self;
} /* launchCompleteAccess: */


- connectCompleteAccess:sender;
{
	fConnection = [NXConnection connectToName:CA_COMPLETE_ACCESS_NAME];
	return self;
} /* connectCompleteAccess: */


- disconnectCompleteAccess:sender;
{
	[fConnection free];
	fConnection = nil;
	return self;
} /* disconnectCompleteAccess: */



/*********************/
/* Container Methods */
/*********************/

- containerClose:sender;
{
	[[fContainer delegate] closeContainerWindow];
	return self;
} /* containerClose: */


- containerOpen:sender;
{
	const char	*appname;
	const char	*filename;
	const char	*ptr;
	char			privatePath[MAXPATHLEN+1];

	/* Assume the container is in the same folder as the application */
	appname = [NXApp appName];
	filename = [[Application workspace] getFullPathForApplication:appname];
	filename = (ptr=strchr(filename, ':')) ? ++ptr : filename;
	strcpy(privatePath, filename);
	filename = strrchr(privatePath, '/');
	if (filename)
		*(++filename) = '\0';
	strcat(privatePath, "DBKitContainer.access");

	/* Open the container */
	fContainer = [fConnection openContainerNamed:privatePath];
	
	return self;
} /* containerOpen: */



/*****************/
/* Query Methods */
/*****************/

- executeQuery:sender;
{
	id			dataSet;
	id			dataAccess;
	int		tag;
	
	/* Get the data access class for importing records */	
	dataSet = [self dataSet];
	dataAccess = [dataSet getDataAccessOfClass:DATA_ACCESS_DBKIT];

	/* Clear data from data set, this is optional since you can incremenatally
		build a data set through consecutive queries */
	[dataSet resetData];

	tag = [[fQueryMatrix selectedCell] tag];
	switch (tag) {
		case 0:		// Query Component
			[dataAccess executeQueryNamed:"Select All"];
			break;
		
		case 1:		// DBQualifier
		//	database = [dataAccess database];
			[dataAccess executeQualifier:nil withSortOrder:nil];
			break;
		
		case 2:		// DBRecordList
		// create DBRecordList, perform query, pass recordList to dataAccess
		//	database = [dataAccess database];
		// [dataAccess recordList2DataSet:recordList];
			break;
		
		case 3:		// DBBinder
		// create DBBinder, perform query, pass recordList to dataAccess
		//	database = [dataAccess database];
		// [dataAccess binder2DataSet:binder];
			break;
	} /* switch */
	
	return self;
} /* executeQuery: */



/*********************/
/* List View Methods */
/*********************/

- listViewClose:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"listView"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[[layoutView delegate] closeLayoutWindow];
	
	return self;
} /* listViewClose: */


- listViewOpen:sender;
{
	id	component;
	
	component = [fContainer getLayoutNamed:"listView"];
	[[fContainer delegate] selectComponent:component];
	[[fContainer delegate] openComponent:component];
	
	return self;
} /* listViewOpen: */


- listViewPrint:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"listView"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[layoutView printPSCode:self];

	return self;
} /* listViewPrint: */



/********************************/
/* Application Delegate Methods */
/********************************/

- (BOOL)shouldRunPrintPanel:view;
/*	Don't automatically run the print panel.
*/
{
	return NO;
} /* shouldRunPrintPanel: */


- appWillTerminate:sender;
{
	[self disconnectCompleteAccess:sender];
	return self;
} /* appWillTerminate: */




@end
