/*	Controller.m

	Ocean Software, Inc.
	1994
*/


#import "Controller.h"
#import "CompleteAccess_API.h"

@implementation Controller

/*******************/
/* Private Methods */
/*******************/

- dataSet;
{
	List	*list;
	id		dataSet;
	
	list = [[List allocFromZone:[self zone]] init];
	[fContainer getDataSets:list];
	dataSet = [list objectAt:0];
	[list free];
	
	return dataSet;
} /* dataSet */



/**********************/
/* Connection Methods */
/**********************/

- launchCompleteAccess:sender;
{
	[[Application workspace] launchApplication:"CompleteAccess"];
	return self;
} /* launchCompleteAccess: */


- connectCompleteAccess:sender;
{
	fConnection = [NXConnection connectToName:CA_COMPLETE_ACCESS_NAME];
	return self;
} /* connectCompleteAccess: */


- disconnectCompleteAccess:sender;
{
	[fConnection free];
	fConnection = nil;
	return self;
} /* disconnectCompleteAccess: */



/*********************/
/* Container Methods */
/*********************/

- containerClose:sender;
{
	[[fContainer delegate] closeContainerWindow];
	return self;
} /* containerClose: */


- containerOpen:sender;
{
	const char	*appname;
	const char	*filename;
	const char	*ptr;
	char			privatePath[MAXPATHLEN+1];

	/* Assume the container is in the same folder as the application */
	appname = [NXApp appName];
	filename = [[Application workspace] getFullPathForApplication:appname];
	filename = (ptr=strchr(filename, ':')) ? ++ptr : filename;
	strcpy(privatePath, filename);
	filename = strrchr(privatePath, '/');
	if (filename)
		*(++filename) = '\0';
	strcat(privatePath, "Congress.access");

	/* Open the container */
	fContainer = [fConnection openContainerNamed:privatePath];
	
	return self;
} /* containerOpen: */


- import:sender;
{
	const char	*appname;
	const char	*filename;
	const char	*ptr;
	id				dataSet;
	id				dataAccess;
	char			importPath[MAXPATHLEN+1];

	/* Assume the import file is in the same folder as the application */
	appname = [NXApp appName];
	filename = [[Application workspace] getFullPathForApplication:appname];
	filename = (ptr=strchr(filename, ':')) ? ++ptr : filename;
	strcpy(importPath, filename);
	filename = strrchr(importPath, '/');
	if (filename)
		*(++filename) = '\0';
	strcat(importPath, "Congress.import");

	/* Get the data access class for importing records */	
	dataSet = [self dataSet];
	dataAccess = [dataSet getDataAccessOfClass:DATA_ACCESS_IMPORT];

	/* Clear data from data set, this is optional since you can incremenatally
		build a data set through consecutive imports */
	[dataSet resetData];
	
	/* Define import file and its properties */
	[dataAccess setImportPath:importPath];
	[dataAccess setFirstLineIsData:YES];
	[dataAccess setFieldDelimiter:"\t"];
	[dataAccess setRecordDelimiter:"\n"];

	/* Read the first line of the import file, create a model to match, and import */
	[dataAccess readStructure];		// Read database structure
	[dataAccess generateModel];		// Make data set's model identical to import data
	[dataAccess smartImport];			// Automatically map import fields to data set model
	[dataAccess setAutoIndex:YES];	// there is no key value in import file
	[dataAccess putRecords];			// perform import
	
	return self;
} /* import: */



/*****************************/
/* Democrat Envelope Methods */
/*****************************/

- demEnvelopeClose:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"Envelope"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[[layoutView delegate] closeLayoutWindow];
	
	return self;
} /* demEnvelopeClose: */


- demEnvelopeOpen:sender;
{
	id	component;
	
	component = [fContainer getLayoutNamed:"Envelope"];
	[[fContainer delegate] selectComponent:component];
	[[fContainer delegate] openComponent:component];
	
	return self;
} /* demEnvelopeOpen: */


- demEnvelopePrint:sender;
{
	id	component;
	id	layoutView;
	unsigned int	recordCount;
	
	component = [fContainer getLayoutNamed:"Envelope"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	recordCount = [layoutView recordCount];
	[layoutView printFromRecord:1 toRecord:2];	// don't really print them all...

	return self;
} /* demEnvelopePrint: */


- demEnvelopeSelect:sender;
{
	return self;
} /* demEnvelopeSelect: */


- demEnvelopeSort:sender;
{
	return self;
} /* demEnvelopeSort: */



/***************************/
/* Democrat Letter Methods */
/***************************/

- demLetterClose:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"Democrat"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[[layoutView delegate] closeLayoutWindow];
	
	return self;
} /* demLetterClose: */


- demLetterOpen:sender;
{
	id	component;
	
	component = [fContainer getLayoutNamed:"Democrat"];
	[[fContainer delegate] selectComponent:component];
	[[fContainer delegate] openComponent:component];
	
	return self;
} /* demLetterOpen: */


- demLetterPrint:sender;
{
	id	component;
	id	layoutView;
	unsigned int	recordCount;
	
	component = [fContainer getLayoutNamed:"Democrat"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	recordCount = [layoutView recordCount];
	[layoutView printFromRecord:1 toRecord:2];	// don't really print them all...

	return self;
} /* demLetterPrint: */


- demLetterSelect:sender;
{
	return self;
} /* demLetterSelect: */


- demLetterSort:sender;
{
	return self;
} /* demLetterSort: */



/*******************************/
/* Republican Envelope Methods */
/*******************************/

- repEnvelopeClose:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"Envelope"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[[layoutView delegate] closeLayoutWindow];
	
	return self;
} /* repEnvelopeClose: */


- repEnvelopeOpen:sender;
{
	id	component;
	
	component = [fContainer getLayoutNamed:"Envelope"];
	[[fContainer delegate] selectComponent:component];
	[[fContainer delegate] openComponent:component];
	
	return self;
} /* repEnvelopeOpen: */


- repEnvelopePrint:sender;
{
	id	component;
	id	layoutView;
	unsigned int	recordCount;
	
	component = [fContainer getLayoutNamed:"Envelope"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	recordCount = [layoutView recordCount];
	[layoutView printFromRecord:1 toRecord:2];	// don't really print them all...

	return self;
} /* repEnvelopePrint: */


- repEnvelopeSelect:sender;
{
	return self;
} /* repEnvelopeSelect: */


- repEnvelopeSort:sender;
{
	return self;
} /* repEnvelopeSort: */



/*****************************/
/* Republican Letter Methods */
/*****************************/

- repLetterClose:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"Republican"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[[layoutView delegate] closeLayoutWindow];
	
	return self;
} /* repLetterClose: */


- repLetterOpen:sender;
{
	id	component;
	
	component = [fContainer getLayoutNamed:"Republican"];
	[[fContainer delegate] selectComponent:component];
	[[fContainer delegate] openComponent:component];
	
	return self;
} /* repLetterOpen: */


- repLetterPrint:sender;
{
	id	component;
	id	layoutView;
	unsigned int	recordCount;
	
	component = [fContainer getLayoutNamed:"Republican"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	recordCount = [layoutView recordCount];
	[layoutView printFromRecord:1 toRecord:2];	// don't really print them all...

	return self;
} /* repLetterPrint: */


- repLetterSelect:sender;
{
	return self;
} /* repLetterSelect: */


- repLetterSort:sender;
{
	return self;
} /* repLetterSort: */



/******************/
/* Report Methods */
/******************/

- reportClose:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"Report"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[[layoutView delegate] closeLayoutWindow];
	
	return self;
} /* reportClose: */


- reportOpen:sender;
{
	id	component;
	
	component = [fContainer getLayoutNamed:"Report"];
	[[fContainer delegate] selectComponent:component];
	[[fContainer delegate] openComponent:component];
	
	return self;
} /* reportOpen: */


- reportPrint:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"Report"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[layoutView printPSCode:self];

	return self;
} /* reportPrint: */



/********************************/
/* Application Delegate Methods */
/********************************/

- (BOOL)shouldRunPrintPanel:view;
/*	Don't automatically run the print panel.
*/
{
	return NO;
} /* shouldRunPrintPanel: */


- appWillTerminate:sender;
{
	[self disconnectCompleteAccess:sender];
	return self;
} /* appWillTerminate: */



@end
