/*	Controller.m

	Ocean Software, Inc.
	1994
*/

#import "Controller.h"
#import "CompleteAccess_API.h"

@implementation Controller


/***********************/
/* Application Methods */
/***********************/

- launchCompleteAccess:sender;
{
	[[Application workspace] launchApplication:"CompleteAccess"];
	return self;
} /* launchCompleteAccess: */



/**********************/
/* Connection Methods */
/**********************/

- connectCompleteAccess:sender;
{
	fConnection = [NXConnection connectToName:CA_COMPLETE_ACCESS_NAME];
	return self;
} /* launchCompleteAccess: */


- disconnectCompleteAccess:sender;
{
	[fConnection free];
	fConnection = nil;
	return self;
} /* disconnectCompleteAccess: */



/*********************/
/* Container Methods */
/*********************/

- openContainer:sender;
{
	const char	*appname;
	const char	*filename;
	const char	*ptr;
	char			privatePath[MAXPATHLEN+1];

	/* Assume the container is in the same folder as the application */
	appname = [NXApp appName];
	filename = [[Application workspace] getFullPathForApplication:appname];
	filename = (ptr=strchr(filename, ':')) ? ++ptr : filename;
	strcpy(privatePath, filename);
	filename = strrchr(privatePath, '/');
	if (filename)
		*(++filename) = '\0';
	strcat(privatePath, "TestContainer.access");

	/* Open the container */
	fContainer = [fConnection openContainerNamed:privatePath];
	
	return self;
} /* openContainer: */


- closeContainer:sender;
{
	[[fContainer delegate] closeContainerWindow];
	return self;
} /* closeContainer: */



/******************/
/* Report Methods */
/******************/

- openReport:sender;
{
	id	component;
	
	component = [fContainer getLayoutNamed:"myReport"];
	[[fContainer delegate] selectComponent:component];
	[[fContainer delegate] openComponent:component];
	
	return self;
} /* openReport: */


- printReport:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"myReport"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[layoutView printPSCode:self];

	return self;
} /* printReport: */


- closeReport:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"myReport"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[[layoutView delegate] closeLayoutWindow];
	
	return self;
} /* closeReport: */



/***********************/
/* Form Letter Methods */
/***********************/

- openForm:sender;
{
	id	component;
	
	component = [fContainer getLayoutNamed:"myForm"];
	[[fContainer delegate] selectComponent:component];
	[[fContainer delegate] openComponent:component];
	
	return self;
} /* openForm: */


- printAllForms:sender;
{
	id	component;
	id	layoutView;
	unsigned int	recordCount;
	
	component = [fContainer getLayoutNamed:"myForm"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	recordCount = [layoutView recordCount];
	[layoutView printFromRecord:1 toRecord:recordCount];

	return self;
} /* printAllForms: */


- printFormAtRecord5:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"myForm"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[layoutView printFromRecord:5 toRecord:5];

	return self;
} /* printFormAtRecord5: */


- closeForm:sender;
{
	id	component;
	id	layoutView;
	
	component = [fContainer getLayoutNamed:"myForm"];
	layoutView = [[fContainer delegate] layout2LayoutView:component];
	[[layoutView delegate] closeLayoutWindow];
	
	return self;
} /* closeForm: */



/********************************/
/* Application Delegate Methods */
/********************************/

- (BOOL)shouldRunPrintPanel:view;
/*	Don't automatically run the print panel.
*/
{
	return NO;
} /* shouldRunPrintPanel: */


- appWillTerminate:sender;
{
	[self disconnectCompleteAccess:sender];
	return self;
} /* appWillTerminate: */



@end
