/*	CA_Container.h

	Ocean Software, Inc.
	1995
*/

#import <appkit/appkit.h>

@interface CA_Container: Object

/* Factory Methods */
+ pathname2container:(const char *)pathname;
+ pathname2container:(const char *)pathname
			fromZone:(NXZone *)zone;
+ (const char *)error2msg:(int)error;

/* Initialization/Free Methods */
- init;
- initWithName:(const char *)name;
- free;
- reset;
- setDefaultComponents;

/* Archive Methods */
- read:(NXTypedStream *)typedStream;
- write:(NXTypedStream *)typedStream;

/* Error Methods */
- (int)fileIOError;
- (int)errorCode;
- (const char *)errorMessage;

/* Delegate Methods */
- delegate;
- setDelegate:delegate;

/* File I/O Methods */
- (BOOL)hasBeenSaved;
- (BOOL)saveData;
- setSaveData:(BOOL)saveData;
- (const char *)name;
- setName:(const char *)name;
- (const char *)pathname;
- setPathname:(const char *)pathname;
- (int)saveContainer:(const char *)pathname;
- (int)saveCopyOfComponent:component;
- (int)revertContainer;
- (const char *)rootEntityName;

/* Layout View Methods */
- layoutViews;

/* Calculation Methods */
- (BOOL)autoRecalc;
- setAutoRecalc:(BOOL)autoRecalc;
- invalidateCalculations;
- recalc;
- performRecalc;

/* Import/Export Components */
- importScenarios;
- exportScenarios;

/* Container Components */
- dataSet;
- dataSets;
- calculations;
- layouts;
- queries;
- variables;
- componentType2components:(int)type;

/* Other Container Components */
- getDataSetNamed:(const char *)name;
- getLayoutNamed:(const char *)name;
- getQueryNamed:(const char *)name;
- getCalculationNamed:(const char *)name;
- getVariableNamed:(const char *)name;

/* New Component Methods */
- newCalculation;
- newDataSet;	
- newLayout;	
- newQuery;		
- newVariable;	
- newComponentOfType:(int)componentType;

/* Layout Methods */
- reflowRecords;
- reflowRecordsForLayout:layout;
- redrawLayouts;

/* Target/Action Methods */
- recalculate:sender;
- reset:sender;

@end


@interface CA_Container(DelegateMethods)
- (BOOL)showDataInSQLJournal:container;		// NEW
- resetSQLJournalForContainer:container;		// NEW
- addSQLJournalText:(const char *)text
			forContainer:container;					// NEW

- willImportRecords:container;					// NEW
- didImportRecords:container;						// NEW
- didAbortImport:container;						// NEW
- (BOOL)didImportAnotherRecord:container;		// NEW

- willExportRecords:container;					// NEW
- didExportRecords:container;						// NEW
- didAbortExport:container;						// NEW
- (BOOL)didExportAnotherRecord:container;		// NEW

@end
