/*	LayoutView.h

	Ocean Software, Inc.
	1995
*/

#import <appkit/appkit.h>

@interface LayoutView: View

/* Initialization methods */
- initFrame:(const NXRect *)frameRect;
- initFrame:(const NXRect *)frameRect
			withLayout:(CA_Layout *)layout;

- delegate;
- setDelegate:delegate;

/* Layout/Collection Methods */
- dataSet;
- container;
- layout;
- setLayout:layout;
- (int)layoutType;
- docView;

/* Calculation Methods */
- performRecalc;
- invalidateCalculations;

/* Print attributes */
- (BOOL)printBackToFront;									// NEW
- setPrintBackToFront:(BOOL)printBackToFront;		// NEW
- (int)printMode;												// NEW
- setPrintMode:(int)printFrontToBack;					// NEW

/* Email Methods */
- emailRecipient;
- setEmailRecipient:emailRecipient;
- (const char *)emailSubject;
- setEmailSubject:(const char *)emailSubject;
- (BOOL)emailAutosend;
- setEmailAutosend:(BOOL)emailAutosend;

/* Fax Methods */
- faxNumberElt;
- setFaxNumberElt:faxNumberElt;
- faxRecipient;
- setFaxRecipient:faxRecipient;
- (BOOL)faxReceipt;
- setFaxReceipt:(BOOL)faxReceipt;
- (BOOL)faxFine;
- setFaxFine:(BOOL)faxFine;
- (BOOL)faxTrimPages;
- setFaxTrimPages:(BOOL)faxTrimPages;
- (BOOL)faxCoverSheet;
- setFaxCoverSheet:(BOOL)faxCoverSheet;

/* Sort/Filter/Omit methods */
- sortOrder;								// NEW API
- setSortOrder:sortOrder;				// NEW API
- filter;									// NEW API
- setFilter:filter;						// NEW API
- applySort;
- applyFilter;
- omitMultiple:(int)numRecords
			startingAtRecord:(unsigned int)recNum;

/* Cursor Positioning Methods */
- setFirst;
- setLast;
- setNext;
- setPrevious;
- setTo:(unsigned int)recNum;
- (unsigned int)currentPosition;
- (unsigned int)recordCount;
- (BOOL)hasEmptySelection;

/* Page Number Methods */
- (int)currentPage;
- (int)startingPage;
- (int)totalPages;
- (int)startingPageNumber;
- setStartingPageNumber:(int)pgNumber;

/* Find methods */
- (BOOL)findText:(const char *)string
			ignoreCase:(BOOL)ignoreCaseflag
			backwards:(BOOL)backwardsflag
			wrap:(BOOL)wrapflag;

/* Printing Methods */
- (BOOL)shouldRunAbortPanel;
- setShouldRunAbortPanel:(BOOL)shouldRunAbortPanel;
- printReport:sender;											// NEW
- printFromRecord:(unsigned int)fromRecord
			toRecord:(unsigned int)toRecord;
- previewFromRecord:(unsigned int)fromRecord
			toRecord:(unsigned int)toRecord;
- saveToFileFromRecord:(unsigned int)fromRecord
			toRecord:(unsigned int)toRecord
			modelPathForFilename:(const char *)modelPath;
- emailFromRecord:(unsigned int)fromRecord
			toRecord:(unsigned int)toRecord;
- faxFromRecord:(unsigned int)fromRecord
			toRecord:(unsigned int)toRecord
			sendAt:(time_t)when
			faxName:(const char *)aString;

@end

